@@ -20,7 +20,7 @@
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
   
-   Author: Darin Adler <darin@eazel.com>
+   Author: Darin Adler <darin@bentspoon.com>
 */
 
 #include <config.h>
@@ -46,6 +46,7 @@ typedef struct {
 	gpointer callback_data;
 
 	GList *wait_for_attributes;
+	gboolean wait_for_file_list;
 
 	GList *non_ready_directories;
 	GList *merged_file_list;
@@ -205,6 +206,7 @@ directory_ready_callback (NautilusDirectory *directory,
 static void
 merged_call_when_ready (NautilusDirectory *directory,
 			GList *file_attributes,
+			gboolean wait_for_file_list,
 			NautilusDirectoryCallback callback,
 			gpointer callback_data)
 {
@@ -228,6 +230,7 @@ merged_call_when_ready (NautilusDirectory *directory,
 	merged_callback->callback = callback;
 	merged_callback->callback_data = callback_data;
 	merged_callback->wait_for_attributes = eel_g_str_list_copy (file_attributes);
+	merged_callback->wait_for_file_list = wait_for_file_list;
 	for (node = merged->details->directories; node != NULL; node = node->next) {
 		merged_callback->non_ready_directories = g_list_prepend
 			(merged_callback->non_ready_directories, node->data);
@@ -247,6 +250,7 @@ merged_call_when_ready (NautilusDirectory *directory,
 		nautilus_directory_call_when_ready
 			(node->data,
 			 merged_callback->wait_for_attributes,
+			 merged_callback->wait_for_file_list,
 			 directory_ready_callback, merged_callback);
 	}
 }
@@ -282,17 +286,32 @@ merged_cancel_callback (NautilusDirectory *directory,
 	merged_callback_destroy (merged_callback);
 }
 
+static void
+build_merged_callback_list (NautilusDirectory *directory,
+			    GList *file_list,
+			    gpointer callback_data)
+{
+	GList **merged_list;
+
+	merged_list = callback_data;
+	*merged_list = g_list_concat (*merged_list,
+				      nautilus_file_list_copy (file_list));
+}
+
 /* Create a monitor on each of the directories in the list. */
 static void
 merged_file_monitor_add (NautilusDirectory *directory,
 			 gconstpointer client,
 			 gboolean monitor_hidden_files,
 			 gboolean monitor_backup_files,
-			 GList *file_attributes)
+			 GList *file_attributes,
+			 NautilusDirectoryCallback callback,
+			 gpointer callback_data)
 {
 	NautilusMergedDirectory *merged;
 	MergedMonitor *monitor;
 	GList *node;
+	GList *merged_callback_list;
 
 	merged = NAUTILUS_MERGED_DIRECTORY (directory);
 
@@ -314,12 +333,18 @@ merged_file_monitor_add (NautilusDirectory *directory,
 	monitor->monitor_attributes = eel_g_str_list_copy (file_attributes);
 	
 	/* Call through to the real directory add calls. */
+	merged_callback_list = NULL;
 	for (node = merged->details->directories; node != NULL; node = node->next) {
 		nautilus_directory_file_monitor_add
 			(node->data, monitor,
 			 monitor_hidden_files, monitor_backup_files,
-			 file_attributes);
+			 file_attributes,
+			 build_merged_callback_list, &merged_callback_list);
 	}
+	if (callback != NULL) {
+		(* callback) (directory, merged_callback_list, callback_data);
+	}
+	nautilus_file_list_free (merged_callback_list);
 }
 
 /* Remove the monitor from each of the directories in the list. */
@@ -419,17 +444,17 @@ merged_is_not_empty (NautilusDirectory *directory)
 static void
 forward_files_added_cover (NautilusDirectory *real_directory,
 			   GList *files,
-			   NautilusMergedDirectory *merged)
+			   gpointer callback_data)
 {
-	nautilus_directory_emit_files_added (NAUTILUS_DIRECTORY (merged), files);
+	nautilus_directory_emit_files_added (NAUTILUS_DIRECTORY (callback_data), files);
 }
 
 static void
 forward_files_changed_cover (NautilusDirectory *real_directory,
 			     GList *files,
-			     NautilusMergedDirectory *merged)
+			     gpointer callback_data)
 {
-	nautilus_directory_emit_files_changed (NAUTILUS_DIRECTORY (merged), files);
+	nautilus_directory_emit_files_changed (NAUTILUS_DIRECTORY (callback_data), files);
 }
 
 static void
@@ -455,7 +480,8 @@ monitor_add_directory (gpointer key,
 		(NAUTILUS_DIRECTORY (callback_data), monitor,
 		 monitor->monitor_hidden_files,
 		 monitor->monitor_backup_files,
-		 monitor->monitor_attributes);
+		 monitor->monitor_attributes,
+		 forward_files_added_cover, monitor->merged);
 }
 
 static void
@@ -474,7 +500,21 @@ merged_add_real_directory (NautilusMergedDirectory *merged,
 	merged->details->directories_not_done_loading = g_list_prepend
 		(merged->details->directories_not_done_loading, real_directory);
 
-	/* Connect signals. */
+	gtk_signal_connect (GTK_OBJECT (real_directory),
+			    "done_loading",
+			    done_loading_callback,
+			    merged);
+
+	/* FIXME bugzilla.gnome.org 45084: The done_loading part won't work for the case where
+         * we have no directories in our list.
+	 */
+
+	/* Add the directory to any extant monitors. */
+	g_hash_table_foreach (merged->details->monitors,
+			      monitor_add_directory,
+			      real_directory);
+	/* FIXME bugzilla.gnome.org 42541: Do we need to add the directory to callbacks too? */
+
 	gtk_signal_connect (GTK_OBJECT (real_directory),
 			    "files_added",
 			    forward_files_added_cover,
@@ -483,20 +523,6 @@ merged_add_real_directory (NautilusMergedDirectory *merged,
 			    "files_changed",
 			    forward_files_changed_cover,
 			    merged);
-	gtk_signal_connect (GTK_OBJECT (real_directory),
-			    "done_loading",
-			    done_loading_callback,
-			    merged);
-
-	/* FIXME bugzilla.eazel.com 5084: The done_loading part won't work for the case where
-         * we have no directories in our list.
-	 */
-
-	/* Add the directory to any extant monitors. */
-	g_hash_table_foreach (merged->details->monitors,
-			      monitor_add_directory,
-			      real_directory);
-	/* FIXME bugzilla.eazel.com 2541: Do we need to add the directory to callbacks too? */
 }
 
 void
