@@ -20,7 +20,7 @@
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
   
-   Author: Darin Adler <darin@eazel.com>
+   Author: Darin Adler <darin@bentspoon.com>
 */
 
 #include <config.h>
@@ -39,8 +39,8 @@ static void nautilus_vfs_file_initialize       (gpointer   object,
 static void nautilus_vfs_file_initialize_class (gpointer   klass);
 
 EEL_DEFINE_CLASS_BOILERPLATE (NautilusVFSFile,
-				   nautilus_vfs_file,
-				   NAUTILUS_TYPE_FILE)
+			      nautilus_vfs_file,
+			      NAUTILUS_TYPE_FILE)
 
 static void             
 vfs_file_monitor_add (NautilusFile *file,
@@ -49,7 +49,7 @@ vfs_file_monitor_add (NautilusFile *file,
 {
 	nautilus_directory_monitor_add_internal
 		(file->details->directory, file,
-		 client, TRUE, TRUE, attributes);
+		 client, TRUE, TRUE, attributes, NULL, NULL);
 }   
 			   
 static void
@@ -245,6 +245,12 @@ nautilus_vfs_file_initialize (gpointer object, gpointer klass)
 static void
 vfs_destroy (GtkObject *object)
 {
+	NautilusVFSFile *file;
+
+	file = NAUTILUS_VFS_FILE (object);
+
+	g_free (file->details);
+	
 	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
 }
 
