@@ -46,7 +46,7 @@
 #include <eel/eel-string.h>
 #include <eel/eel-vfs-extensions.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include <gnome-xml/parser.h>
+#include <libxml/parser.h>
 #include <gtk/gtkcheckmenuitem.h>
 #include <gtk/gtkdnd.h>
 #include <gtk/gtkhbox.h>
@@ -127,7 +127,7 @@ static void     background_metadata_changed_callback   (NautilusSidebar  *sideba
 
 #define DEFAULT_TAB_COLOR "rgb:9999/9999/9999"
 
-/* FIXME bugzilla.eazel.com 1245: hardwired sizes */
+/* FIXME bugzilla.gnome.org 41245: hardwired sizes */
 #define SIDEBAR_MINIMUM_WIDTH 1
 #define SIDEBAR_MINIMUM_HEIGHT 400
 
@@ -145,6 +145,7 @@ enum {
 	TARGET_COLOR,
 	TARGET_BGIMAGE,
 	TARGET_KEYWORD,
+	TARGET_BACKGROUND_RESET,
 	TARGET_GNOME_URI_LIST
 };
 
@@ -153,6 +154,7 @@ static GtkTargetEntry target_table[] = {
 	{ "application/x-color", 0, TARGET_COLOR },
 	{ "property/bgimage", 0, TARGET_BGIMAGE },
 	{ "property/keyword", 0, TARGET_KEYWORD },
+	{ "x-special/gnome-reset-background", 0, TARGET_BACKGROUND_RESET },	
 	{ "x-special/gnome-icon-list",  0, TARGET_GNOME_URI_LIST }
 };
 
@@ -313,6 +315,8 @@ nautilus_sidebar_destroy (GtkObject *object)
 		nautilus_file_unref (sidebar->details->file);
 	}
 
+	gtk_object_sink (GTK_OBJECT (sidebar->details->title_tab));
+	
 	g_free (sidebar->details->uri);
 	g_free (sidebar->details->default_background_color);
 	g_free (sidebar->details->default_background_image);
@@ -337,7 +341,7 @@ reset_background_callback (GtkWidget *menu_item, GtkWidget *sidebar)
 {
 	EelBackground *background;
 
-	background = eel_get_widget_background(sidebar);
+	background = eel_get_widget_background (sidebar);
 	if (background != NULL) { 
 		eel_background_reset (background); 
 	}
@@ -698,7 +702,7 @@ receive_dropped_uri_list (NautilusSidebar *sidebar,
 	switch (hit_test (sidebar, x, y)) {
 	case NO_PART:
 	case BACKGROUND_PART:
-		/* FIXME bugzilla.eazel.com 2507: Does this work for all images, or only background images?
+		/* FIXME bugzilla.gnome.org 42507: Does this work for all images, or only background images?
 		 * Other views handle background images differently from other URIs.
 		 */
 		if (exactly_one && uri_is_local_image (uris[0])) {
@@ -854,6 +858,7 @@ nautilus_sidebar_drag_data_received (GtkWidget *widget, GdkDragContext *context,
 					 guint info, guint time)
 {
 	NautilusSidebar *sidebar;
+	EelBackground *background;
 
 	g_return_if_fail (NAUTILUS_IS_SIDEBAR (widget));
 
@@ -871,6 +876,12 @@ nautilus_sidebar_drag_data_received (GtkWidget *widget, GdkDragContext *context,
 		if (hit_test (sidebar, x, y) == BACKGROUND_PART)
 			receive_dropped_uri_list (sidebar, x, y, selection_data);
 		break;	
+	case TARGET_BACKGROUND_RESET:
+		background = eel_get_widget_background ( GTK_WIDGET (sidebar));
+		if (background != NULL) { 
+			eel_background_reset (background); 
+		}
+		break;
 	case TARGET_KEYWORD:
 		receive_dropped_keyword (sidebar, x, y, selection_data);
 		break;
@@ -1345,7 +1356,7 @@ add_command_buttons (NautilusSidebar *sidebar, GList *application_list)
 				    FALSE, FALSE, 
 				    0);
 
-		/* FIXME bugzilla.eazel.com 2510: Security hole?
+		/* FIXME bugzilla.gnome.org 42510: Security hole?
 		 * Unsafe to use a string from the MIME file as a
 		 * printf format string without first checking it over
 		 * somehow. We can do a search and replace on the "%s"
